<template>
  <a-card :bordered='false'>

    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form layout='inline' @keyup.enter.native='searchQuery'>
        <a-row :gutter='24'>
          <a-col :lg='7' :md='8' :sm='24' :xl='4'>
            <a-form-item label='设备编号'>
              <lx-search-equipment-select v-model='queryParam.equipmentId'
                                          placeholder='请输入设备编号或名称搜索'></lx-search-equipment-select>
            </a-form-item>
          </a-col>
          <a-col :lg='7' :md='8' :sm='24' :xl='4'>
            <a-form-item label='单据号'>
              <a-input v-model='queryParam.code' placeholder='请输入单据号'></a-input>
            </a-form-item>
          </a-col>
          <a-col :lg='7' :md='8' :sm='24' :xl='6'>
            <span class='table-page-search-submitButtons' style='float: left;overflow: hidden;'>
              <a-button icon='search' type='primary' @click='searchQuery'>查询</a-button>
              <a-button icon='reload' style='margin-left: 8px' type='info' @click='searchReset'>重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class='table-operator'>
      <a-button icon='plus' type='primary' @click='handleAdd'>新增</a-button>
      <!--      <a-button type="primary" icon="download" @click="handleExportXls('设备封存启封')">导出</a-button>-->
      <!--      <a-upload name="file" :showUploadList="false" :multiple="false" :headers="tokenHeader" :action="importExcelUrl" @change="handleImportExcel">-->
      <!--        <a-button type="primary" icon="import">导入</a-button>-->
      <!--      </a-upload>-->
      <a-dropdown v-if='selectedRowKeys.length > 0'>
        <a-menu slot='overlay'>
          <a-menu-item key='1' @click='batchDel'>
            <a-icon type='delete' />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style='margin-left: 8px'> 批量操作
          <a-icon type='down' />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class='ant-alert ant-alert-info' style='margin-bottom: 16px;'>
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a style='margin-left: 24px' @click='onClearSelected'>清空</a>
      </div>

      <a-table
        ref='table'
        :columns='columns'
        :dataSource='dataSource'
        :loading='loading'
        :pagination='ipagination'
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        bordered
        class='j-table-force-nowrap'
        rowKey='id'
        size='middle'
        @change='handleTableChange'>

        <span slot='action' slot-scope='text, record'>
           <template v-if="record.sealStatus === 'WAIT_SUBMIT'">
            <a-popconfirm title='确定提交吗?' @confirm='() => handleSubmit(record.id)'>
              <a>提交</a>
            </a-popconfirm>
              <a-divider type='vertical' />
               <a @click='handleEdit(record)'>编辑</a>
          <a-divider type='vertical' />
             <a-popconfirm title='确定删除吗?' @confirm='() => handleDelete(record.id)'>
                  <a>删除</a>
                </a-popconfirm>
           </template>
          <template v-else>
              <a @click='handleDetail(record)'>详情</a>
          </template>
        </span>

      </a-table>
    </div>
    <!-- table区域-end -->

    <!-- 表单区域 -->
    <eamEquipmentSealUp-modal ref='modalForm' @ok='modalFormOk'></eamEquipmentSealUp-modal>
  </a-card>
</template>

<script>
import '@/assets/less/TableExpand.less'
import EamEquipmentSealUpModal from './modules/EamEquipmentSealUpModal'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import LxSearchEquipmentSelect from '@views/eam/equipment/modules/LxSearchEquipmentSelect.vue'
import { getAction } from '@api/manage'

export default {
  name: 'EamEquipmentSealUpList',
  mixins: [JeecgListMixin],
  components: {
    EamEquipmentSealUpModal,
    LxSearchEquipmentSelect
  },
  data() {
    return {
      description: '设备封存启封管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '设备编号',
          align: 'center',
          dataIndex: 'equipmentCode'
        },
        {
          title: '设备名称',
          align: 'center',
          dataIndex: 'equipmentName'
        },
        {
          title: '单据号',
          align: 'center',
          dataIndex: 'code'
        },
        {
          title: '申请人',
          align: 'center',
          dataIndex: 'reportUser_dictText'
        },
        {
          title: '封存开始时间',
          align: 'center',
          dataIndex: 'sealStartTime'
        },
        {
          title: '封存结束时间',
          align: 'center',
          dataIndex: 'sealEndTime'
        },
        {
          title: '封存原因',
          align: 'center',
          dataIndex: 'sealUpReason'
        },
        {
          title: '封存状态',
          align: 'center',
          dataIndex: 'sealStatus_dictText'
        },
        {
          title: '审核人',
          align: 'center',
          dataIndex: 'approvalUser'
        },
        {
          title: '审核时间',
          align: 'center',
          dataIndex: 'approvalTime'
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: '/eam/eamEquipmentSealUp/list',
        delete: '/eam/eamEquipmentSealUp/delete',
        deleteBatch: '/eam/eamEquipmentSealUp/deleteBatch',
        submit: '/eam/eamEquipmentSealUp/submit'
      }
    }
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {
    handleSubmit(id) {
      if (!this.url.submit) {
        this.$message.error('请设置url.submit属性!')
        return
      }
      let that = this
      getAction(that.url.submit, { id: id }).then((res) => {
        if (res.success) {
          //重新计算分页问题
          that.reCalculatePage(1)
          // that.$message.success(res.message);
          that.$notification.success({
            message: '消息',
            description: res.message
          })
          that.loadData()
        } else {
          // that.$message.warning(res.message);
          that.$notification.warning({
            message: '消息',
            description: res.message
          })
        }
      })
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>